@@ -19,6 +19,7 @@ import re
 from coopr.opt.base import results
 from coopr.opt.base.formats import *
 from coopr.opt import SolverResults
+from pyutilib.component.core import alias
 
 
 class ResultsReader_results(results.AbstractResultsReader):
@@ -27,6 +28,8 @@ class ResultsReader_results(results.AbstractResultsReader):
     SolverResults object.
     """
 
+    alias(str(ResultsFormat.yaml))
+
     def __init__(self):
         results.AbstractResultsReader.__init__(self,ResultsFormat.yaml)
 
@@ -40,6 +43,3 @@ class ResultsReader_results(results.AbstractResultsReader):
         res.read(filename)
         return res
 
-
-results.ReaderRegistration(str(ResultsFormat.yaml), ResultsReader_results)
-
