@@ -2,5 +2,5 @@
 from results import *
 from solver import SolverStatus, TerminationCondition
 from problem import ProblemSense
-from solution import SolutionStatus, Solution
+from solution import SolutionStatus, Solution, SolutionMap
 from container import *
