@@ -25,6 +25,9 @@ class ProblemInformation(MapContainer):
         self.declare('number_of_objectives', value=1, required=True)
         self.declare('number_of_constraints', value=0)
         self.declare('number_of_variables', value=0)
+        self.declare('number_of_binary_variables')
+        self.declare('number_of_integer_variables')
+        self.declare('number_of_continuous_variables')
         self.declare('number_of_nonzeros')
         self.declare('sense', value=ProblemSense.unknown, required=True)
         
