@@ -7,7 +7,7 @@
 #  the U.S. Government retains certain rights in this software.
 #  _________________________________________________________________________
 
-__all__ = ['SolutionStatus', 'Solution']
+__all__ = ['SolutionStatus', 'Solution', 'SolutionMap']
 
 import math
 from container import *
@@ -17,9 +17,20 @@ from pyutilib.math import as_number
 
 default_print_options = Bunch(schema=False, sparse=True, num_solutions=None, ignore_time=False, ignore_defaults=False)
 
-SolutionStatus = Enum('globallyOptimal', 'locallyOptimal',
-                            'optimal', 'bestSoFar', 'feasible', 'infeasible', 'stoppedByLimit',
-                            'unknown', 'unsure', 'error', 'other')
+SolutionStatus = Enum(
+  'bestSoFar',
+  'error',
+  'feasible',
+  'globallyOptimal',
+  'infeasible',
+  'locallyOptimal',
+  'optimal',
+  'other',
+  'stoppedByLimit',
+  'unbounded',
+  'unknown',
+  'unsure',
+)
 
 
 class SolutionMap(MapContainer):
