@@ -11,13 +11,17 @@
 __all__ = ['TestCase']
 
 import os
-import pyutilib.th
+import pyutilib.th as unittest
 import copy
 import pyutilib.subprocess
 from coopr.opt import SolverResults
 import re
 import pyutilib.misc
-
+try:
+    import yaml
+    using_yaml=True
+except ImportError:
+    using_yaml=False
 
 def _failIfCooprResultsDiffer(self, cmd=None, baseline=None, cwd=None):
     if cwd is not None:
@@ -39,16 +43,17 @@ def _failIfCooprResultsDiffer(self, cmd=None, baseline=None, cwd=None):
         self.fail("Difference between results and baseline: '%s'" % str(err))
 
 
-class TestCase(pyutilib.th.TestCase):
+class TestCase(unittest.TestCase):
 
     def __init__(self, methodName='runTest'):
-        pyutilib.th.TestCase.__init__(self, methodName)
+        unittest.TestCase.__init__(self, methodName)
 
     def failIfCooprResultsDiffer(self, cmd, baseline, cwd=None):
         if not using_yaml:
             self.fail("Cannot compare Coopr results because PyYaml is not installed")
         _failIfCooprresultsDiffer(self, cmd=cmd, baseline=baseline, cwd=cwd)
 
+    @unittest.nottest
     def add_coopr_results_test(name=None, cmd=None, fn=None, baseline=None):
         if not using_yaml:
             return
