@@ -37,13 +37,13 @@ class OptConfigDebug(unittest.TestCase):
         app.save_configuration(currdir+"opt1-out.cfg")
         app.configure(currdir+"opt1.cfg")
         if pyutilib.services.registered_executable("pico_convert"):
-            self.failUnlessEqual( pyutilib.services.registered_executable("pico_convert").get_path(), pyutilib.misc.search_file("pico_convert"))
+            self.assertEqual( pyutilib.services.registered_executable("pico_convert").get_path(), pyutilib.misc.search_file("pico_convert"))
         if pyutilib.services.registered_executable("glpsol"):
-            self.failUnlessEqual( pyutilib.services.registered_executable("glpsol").get_path(), pyutilib.misc.search_file("glpsol"))
+            self.assertEqual( pyutilib.services.registered_executable("glpsol").get_path(), pyutilib.misc.search_file("glpsol"))
         if pyutilib.services.registered_executable("ampl"):
-            self.failUnlessEqual( pyutilib.services.registered_executable("ampl").get_path(), pyutilib.misc.search_file("ampl"))
+            self.assertEqual( pyutilib.services.registered_executable("ampl").get_path(), pyutilib.misc.search_file("ampl"))
         if pyutilib.services.registered_executable("timer"):
-            self.failUnlessEqual( pyutilib.services.registered_executable("timer").get_path(), pyutilib.misc.search_file("timer"))
+            self.assertEqual( pyutilib.services.registered_executable("timer").get_path(), pyutilib.misc.search_file("timer"))
 
 
 if __name__ == "__main__":
