@@ -69,36 +69,36 @@ class Test(unittest.TestCase):
         Testing the coopr.opt solver factory
         """
         ans = sorted(coopr.opt.SolverFactory.services())
-        #self.failUnlessEqual(len(ans),8)
-        self.failUnless(set(['stest']) <= set(ans))
+        #self.assertEqual(len(ans),8)
+        self.assertTrue(set(['stest']) <= set(ans))
 
     def test_solver_instance(self):
         """
         Testing that we get a specific solver instance
         """
         ans = coopr.opt.SolverFactory("none")
-        self.failUnlessEqual(ans, None)
+        self.assertEqual(ans, None)
         ans = coopr.opt.SolverFactory("stest")
-        self.failUnlessEqual(type(ans), TestSolver)
+        self.assertEqual(type(ans), TestSolver)
         ans = coopr.opt.SolverFactory("stest", name="mymock")
-        self.failUnlessEqual(type(ans), TestSolver)
-        self.failUnlessEqual(ans.name,  "mymock")
+        self.assertEqual(type(ans), TestSolver)
+        self.assertEqual(ans.name,  "mymock")
 
     def test_solver_registration(self):
         """
         Testing methods in the solverwriter factory registration process
         """
         coopr.opt.SolverFactory.deactivate("stest")
-        self.failUnless(not 'stest' in coopr.opt.SolverFactory.services())
+        self.assertTrue(not 'stest' in coopr.opt.SolverFactory.services())
         coopr.opt.SolverFactory.activate("stest")
-        self.failUnless('stest' in coopr.opt.SolverFactory.services())
+        self.assertTrue('stest' in coopr.opt.SolverFactory.services())
 
     def test_writer_factory(self):
         """
         Testing the coopr.opt writer factory
         """
         factory = coopr.opt.WriterFactory.services()
-        self.failUnless(set(['wtest']) <= set(factory))
+        self.assertTrue(set(['wtest']) <= set(factory))
 
     def test_writer_instance(self):
         """
@@ -108,21 +108,18 @@ class Test(unittest.TestCase):
         later it should be adapted to generate a specific writer.
         """
         ans = coopr.opt.WriterFactory("none")
-        self.failUnlessEqual(ans, None)
+        self.assertEqual(ans, None)
         ans = coopr.opt.WriterFactory("wtest")
-        self.failIfEqual(ans, None)
-        #ans = coopr.opt.WriterFactory("wtest", "mywriter")
-        #self.failIfEqual(ans, None)
-        #self.failIfEqual(ans.name, "mywriter")
+        self.assertNotEqual(ans, None)
 
     def test_writer_registration(self):
         """
         Testing methods in the writer factory registration process
         """
         coopr.opt.WriterFactory.deactivate("wtest")
-        self.failUnless(not 'wtest' in coopr.opt.WriterFactory.services())
+        self.assertTrue(not 'wtest' in coopr.opt.WriterFactory.services())
         coopr.opt.WriterFactory.activate("wtest")
-        self.failUnless('wtest' in coopr.opt.WriterFactory.services())
+        self.assertTrue('wtest' in coopr.opt.WriterFactory.services())
 
 
     def test_reader_factory(self):
@@ -130,28 +127,28 @@ class Test(unittest.TestCase):
         Testing the coopr.opt reader factory
         """
         ans = coopr.opt.ReaderFactory.services()
-        self.failUnless(set(ans) >= set(["rtest", "sol","yaml"]))
+        self.assertTrue(set(ans) >= set(["rtest", "sol","yaml"]))
 
     def test_reader_instance(self):
         """
         Testing that we get a specific reader instance
         """
         ans = coopr.opt.ReaderFactory("none")
-        self.failUnlessEqual(ans, None)
+        self.assertEqual(ans, None)
         ans = coopr.opt.ReaderFactory("sol")
-        self.failUnlessEqual(type(ans), coopr.opt.reader.sol.ResultsReader_sol)
+        self.assertEqual(type(ans), coopr.opt.reader.sol.ResultsReader_sol)
         #ans = coopr.opt.ReaderFactory("osrl", "myreader")
-        #self.failUnlessEqual(type(ans), coopr.opt.reader.OS.ResultsReader_osrl)
-        #self.failUnlessEqual(ans.name, "myreader")
+        #self.assertEqual(type(ans), coopr.opt.reader.OS.ResultsReader_osrl)
+        #self.assertEqual(ans.name, "myreader")
 
     def test_reader_registration(self):
         """
         Testing methods in the reader factory registration process
         """
         coopr.opt.ReaderFactory.deactivate("rtest")
-        self.failUnless(not 'rtest' in coopr.opt.ReaderFactory.services())
+        self.assertTrue(not 'rtest' in coopr.opt.ReaderFactory.services())
         coopr.opt.ReaderFactory.activate("rtest")
-        self.failUnless('rtest' in coopr.opt.ReaderFactory.services())
+        self.assertTrue('rtest' in coopr.opt.ReaderFactory.services())
 
 if __name__ == "__main__":
    unittest.main()
