@@ -35,7 +35,7 @@ class Test(unittest.TestCase):
         reader = coopr.opt.ReaderFactory("sol")
         soln = reader(currdir+"test4_sol.sol")
         soln.write(filename=currdir+"factory.txt")
-        self.failUnlessFileEqualsBaseline(currdir+"factory.txt", currdir+"test4_sol.txt")
+        self.assertFileEqualsBaseline(currdir+"factory.txt", currdir+"test4_sol.txt")
         
 
 if __name__ == "__main__":
