@@ -46,16 +46,16 @@ class OptSolverDebug(unittest.TestCase):
         Verify the processing of 'type', 'name' and 'doc' options
         """
         ans = coopr.opt.SolverFactory("stest1")
-        self.failUnlessEqual(type(ans), TestSolver1)
-        self.failUnlessEqual(ans._doc, "TestSolver1 Documentation")
+        self.assertEqual(type(ans), TestSolver1)
+        self.assertEqual(ans._doc, "TestSolver1 Documentation")
 
         ans = coopr.opt.SolverFactory("stest1", doc="My Doc")
-        self.failUnlessEqual(type(ans), TestSolver1)
-        self.failUnlessEqual(ans._doc, "TestSolver1 Documentation")
+        self.assertEqual(type(ans), TestSolver1)
+        self.assertEqual(ans._doc, "TestSolver1 Documentation")
 
         ans = coopr.opt.SolverFactory("stest1", name="my name")
-        self.failUnlessEqual(type(ans), TestSolver1)
-        self.failUnlessEqual(ans._doc, "TestSolver1 Documentation")
+        self.assertEqual(type(ans), TestSolver1)
+        self.assertEqual(ans._doc, "TestSolver1 Documentation")
 
     def test_solver_init2(self):
         """
@@ -65,8 +65,8 @@ class OptSolverDebug(unittest.TestCase):
         opt['a'] = 1
         opt['b'] = "two"
         ans = coopr.opt.SolverFactory("stest1", name="solver_init2", options=opt)
-        self.failUnlessEqual(ans.options['a'], opt['a'])
-        self.failUnlessEqual(ans.options['b'], opt['b'])
+        self.assertEqual(ans.options['a'], opt['a'])
+        self.assertEqual(ans.options['b'], opt['b'])
 
     def test_avail(self):
         ans = coopr.opt.SolverFactory("stest1")
